Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(181)

Unified Diff: src/dateparser.h

Issue 1403153003: Revert of Make dates default to the local timezone if none specified (https://codereview.chromium.… (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | src/dateparser-inl.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/dateparser.h
diff --git a/src/dateparser.h b/src/dateparser.h
index ad9ce70ab79145d78fa1fdb484b20327aebbcde6..484e1d3eca881cf9288bc18e27d6f0c93f610416 100644
--- a/src/dateparser.h
+++ b/src/dateparser.h
@@ -352,16 +352,14 @@ class DateParser : public AllStatic {
bool is_iso_date_;
};
// Tries to parse an ES6 Date Time String. Returns the next token
// to continue with in the legacy date string parser. If parsing is
// complete, returns DateToken::EndOfInput(). If terminally unsuccessful,
// returns DateToken::Invalid(). Otherwise parsing continues in the
// legacy parser.
template <typename Char>
- static DateParser::DateToken ParseES6DateTime(
- DateStringTokenizer<Char>* scanner,
- DayComposer* day,
- TimeComposer* time,
+ static DateParser::DateToken ParseES5DateTime(
+ DateStringTokenizer<Char>* scanner, DayComposer* day, TimeComposer* time,
TimeZoneComposer* tz);
};
« no previous file with comments | « no previous file | src/dateparser-inl.h » ('j') | no next file with comments »
@@ -352,16 +352,14 @@ class DateParser : public AllStatic {
bool is_iso_date_;
};
- // Tries to parse an ES6 Date Time String. Returns the next token
+ // Tries to parse an ES5 Date Time String. Returns the next token
// to continue with in the legacy date string parser. If parsing is
// complete, returns DateToken::EndOfInput(). If terminally unsuccessful,

Powered by Google App Engine
This is Rietveld 408576698